---
meta:
    title: Giovanni Search
    description:
layout: component
---

```html:preview
<terra-variable-keyword-search></terra-variable-keyword-search>
```

## Examples

### First Example

TODO

### Second Example

TODO

[component-metadata:terra-variable-keyword-search]
